import 'package:businesslibrary/api/firestore_list_api.dart';
import 'package:businesslibrary/data/supplier.dart';
import 'package:businesslibrary/util/lookups.dart';
import 'package:flutter/material.dart';

class FindSupplierPage extends StatefulWidget {
  @override
  _FindSupplierPageState createState() => _FindSupplierPageState();
}

class _FindSupplierPageState extends State<FindSupplierPage> {
  Supplier supplier;
  List<Supplier> suppliers = List();
  List<PrivateSectorType> types = List();
  List<DropdownMenuItem> items = List();
  String sectorType;

  @override
  void initState() {
    super.initState();

    _getTypes();
  }

  _onSupplierTapped(int index) async {
    supplier = suppliers.elementAt(index);
    print(
        '_FindSupplierPageState._onSupplierTapped,  will pop ${supplier.toJson()}');
    Navigator.pop(context, supplier);
  }

  _getTypes() async {
    types = await Lookups.getTypes();
    _buildTypes();
  }

  _buildTypes() {
    types.forEach((sector) {
      var item1 = DropdownMenuItem(
        value: sector.type,
        child: Row(
          children: <Widget>[
            Icon(Icons.apps),
            Text(sector.type),
          ],
        ),
      );
      items.add(item1);
    });
  }

  _getSuppliers() async {
    print('_FindSupplierPageState._getSuppliers ..........');
    suppliers = await FirestoreListAPI.getSuppliersBySector(sectorType);
    setState(() {});
  }

  ListView _buildList() {
    if (suppliers.isEmpty) {
      return ListView();
    }
    return new ListView.builder(
      itemCount: suppliers.length,
      itemBuilder: (BuildContext context, int index) {
        return new Column(
          children: <Widget>[
            new GestureDetector(
              onTap: _onSupplierTapped(index),
              child: new ListTile(
                title: new Text(suppliers[index].name),
                leading: Icon(Icons.build),
              ),
            ),
            new Divider(
              height: 2.0,
            ),
          ],
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Find Supplier'),
        bottom: PreferredSize(
          preferredSize: const Size.fromHeight(60.0),
          child: Container(),
        ),
      ),
      body: new Padding(
        padding: const EdgeInsets.all(8.0),
        child: new Card(
          elevation: 3.0,
          child: Column(
            children: <Widget>[
              Row(
                children: <Widget>[
                  DropdownButton(
                    items: items,
                    hint: Text(
                      'Select Sector',
                      style: TextStyle(color: Colors.blue),
                    ),
                    onChanged: (val) {
                      setState(() {
                        sectorType = val;
                      });
                      _getSuppliers();
                    },
                  ),
                  Text(
                    sectorType == null ? '' : sectorType,
                    style: TextStyle(
                      color: Colors.white,
                      fontWeight: FontWeight.bold,
                    ),
                  )
                ],
              ),
              new Padding(
                padding: const EdgeInsets.all(8.0),
                child: Text(
                  'Suppliers Found',
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    color: Theme.of(context).primaryColor,
                  ),
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
              ),
              _buildList(),
            ],
          ),
        ),
      ),
    );
  }
}
